@@ -36,7 +36,11 @@ def tau_fit(signal, time, neighbors=5):
     for idx in range(neighbors, len(signal) - neighbors):
         if signal[idx] == np.max(signal[idx - neighbors : idx + neighbors]) and signal[idx] > ofs:
             peaks.append(idx)
-    popt, pcov = np.polyfit(time[peaks], np.log(signal[peaks] - ofs), deg=1, cov=True)
+    # Note: weighting proportional to y is used to prevent artificial over
+    # sensitivity to small y values in log-space chi square minimization
+    x, y = time[peaks], np.log(signal[peaks] - ofs)
+    popt, pcov = np.polyfit(x, y, deg=1, w=y, cov=True)
+    #popt[1] = np.exp(popt[1])
     return popt, pcov, peaks
 
 if gen:
@@ -49,7 +53,7 @@ else: t_a, x_a, t_b, x_b = np.loadtxt('./data/beat.txt', unpack = True)
 t_min = 1.8; t_max = 130.
 
 # Preliminary plot to visualize the sub-interval of data to analyze
-if tex: plt.rc('text', usetex=True); plt.rc('font', family='serif')
+lab.rc.typeset(usetex=tex, fontsize=12)
 fig, axs = plt.subplots(2, 1)
 grid(axs[0], xlab='Time [s]', ylab='Pendulum A [ADC counts]')
 grid(axs[1], xlab='Time [s]', ylab='Pendulum B [ADC counts]')
